measuretools.get_first_measure_in_proper_parentage_of_component
===============================================================

.. autofunction:: abjad.tools.measuretools.get_first_measure_in_proper_parentage_of_component.get_first_measure_in_proper_parentage_of_component
